@@ -1,20 +1,7 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2011 Christian Mollekopf <chrigi_1@fastmail.fm>
+    SPDX-FileCopyrightText: 2011 Christian Mollekopf <chrigi_1@fastmail.fm>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef NOTEUTILS_H
@@ -84,6 +71,37 @@ public:
     QByteArray data() const;
 
     /**
+     * Sets the unique identifier of the attachment
+     *
+     * It can be used to refer to attachment from the note itself
+     *
+     * @since 5.15
+     */
+    void setContentID(const QString &contentID);
+
+    /**
+     * Returns the unique identifier for inline attachment
+     *
+     * @since 5.15
+     */
+    QString contentID() const;
+
+   /**
+     * Set this to true if inline data provided via ctor
+     * is alredy base64 encoded. Default value is false.
+     *
+     * @since 5.15
+     */
+    void setDataBase64Encoded(bool encoded);
+
+    /**
+     * Returns true if data is already base64-encoded
+     *
+     * @since 5.15
+     */
+    bool dataBase64Encoded() const;
+
+   /**
      * Returns the mimetype
      */
     QString mimetype() const;
